@@ -1,10 +1,11 @@
-<?php 
-defined('C5_EXECUTE') or die(_("Access Denied."));
-require(dirname(__FILE__) . '/../controller.php');
+<?php  
+defined('C5_EXECUTE') or die("Access Denied.");
 
 $miniSurvey= new Minisurvey();
-
+$bID = $_GET['bID'];
 //Permissions Check
+$bID = $_REQUEST['bID'];
+
 if($_GET['cID'] && $_GET['arHandle']){
 	$c = Page::getByID($_GET['cID'], 'RECENT');
 	$a = Area::get($c, $_GET['arHandle']);  
@@ -15,13 +16,26 @@ if($_GET['cID'] && $_GET['arHandle']){
 		if(!$ap->canAddBlock($bt)) $badPermissions=true;
 	}else{
 		//edit survey mode
-		$b = Block::getByID($_GET['bID'], $c, $a);
+		// this really ought to be refactored
+		if (!$a->isGlobalArea()) {
+			$b = Block::getByID($_REQUEST['bID'], $c, $a);
+			if ($b->getBlockTypeHandle() == BLOCK_HANDLE_SCRAPBOOK_PROXY) {
+				$b = Block::getByID($b->getController()->getOriginalBlockID());
+				$b->setBlockAreaObject($a);
+				$b->loadNewCollection($c);
+				$bID = $b->getBlockID();
+			}
+		} else {
+			$b = Block::getByID($_REQUEST['bID'], Stack::getByName($a->getAreaHandle()), STACKS_AREA_NAME);
+			$b->setBlockAreaObject($a); // set the original area object
+		}
+
 		$bp = new Permissions($b);
 		if( !$bp->canWrite() ) $badPermissions=true;
 	}
 }else $badPermissions=true;
 if($badPermissions){
-	echo 'Invalid Permissions';
+	echo t('Invalid Permissions');
 	die;
 } 
 
@@ -33,7 +47,7 @@ switch ($_GET['mode']){
 		break;
 		
 	case 'getQuestion':
-		$miniSurvey->getQuestionInfo( intval($_GET['qsID']), intval($_GET['msqID']) );
+		$miniSurvey->getQuestionInfo( intval($_GET['qsID']), intval($_GET['qID']) );
 		break;			
 		
 	case 'delQuestion':
@@ -47,7 +61,7 @@ switch ($_GET['mode']){
 	case 'refreshSurvey':
 	default: 
 		$showEdit=(intval($_REQUEST['showEdit'])==1)?true:false; 
-		$miniSurvey->loadSurvey( intval($_GET['qsID']),$showEdit ); 
+		$miniSurvey->loadSurvey( intval($_GET['qsID']), $showEdit, intval($bID), explode(',',$_GET['hide']), 1 ); 
 }
 
-?>
\ No newline at end of file
+?>
